summaryrefslogtreecommitdiff
path: root/deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js')
-rw-r--r--deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js b/deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js
index 8a0a5d5707..a7ab9d18df 100644
--- a/deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js
+++ b/deps/v8/test/mjsunit/harmony/weakrefs/unregister-inside-cleanup4.js
@@ -22,10 +22,10 @@ let cleanup = function(iter) {
++cleanup_call_count;
}
-let fg = new FinalizationGroup(cleanup);
+let fg = new FinalizationRegistry(cleanup);
let key1 = {"k": "first key"};
let key2 = {"k": "second key"};
// Create two objects and register them in the FinalizationGroup. The objects
// need to be inside a closure so that we can reliably kill them!
(function() {
@@ -22,10 +22,10 @@ let cleanup = function(iter) {
let key1 = {"k": "first key"};
let key2 = {"k": "second key"};
-// Create two objects and register them in the FinalizationGroup. The objects
+// Create two objects and register them in the FinalizationRegistry. The objects
// need to be inside a closure so that we can reliably kill them!
(function() {